@@ -36,7 +36,7 @@ with requests.Session() as session:
 
 
     def set_tag(property_name, property_value):
-        tags.append({property_name: property_value})
+        tags.append({f'{property_name}': f'{property_value}'})
 
 
     def info(message, event_time_required=False):
@@ -76,7 +76,7 @@ with requests.Session() as session:
                     installed_packages
                 ),
                 user_info
-            )
+            ).toJSON()
         ]
 
         return create_log(Payload(
@@ -84,8 +84,8 @@ with requests.Session() as session:
             eventTime,
             message,
             json.dumps(tags),
-            json.dumps(detail)
-        ))
+            detail
+        ).toJSON())
 
 
     def error(occurred_error, event_time_required=False):
@@ -127,7 +127,7 @@ with requests.Session() as session:
                     installed_packages
                 ),
                 user_info
-            )
+            ).toJSON()
         ]
 
         return create_log(Payload(
@@ -135,11 +135,11 @@ with requests.Session() as session:
             eventTime,
             message,
             json.dumps(tags),
-            json.dumps(detail)
-        ))
+            detail
+        ).toJSON())
 
 
     def create_log(payload):
         response = session.post(f'{HttpClientConfig.alertNowURL}/integration/appinsight/v1/{user_api_key}',
-                                data=json.dumps(vars(payload)))
+                                data=payload)
         return response
